from win32com.client import Dispatch


def email_with_attachments(
        message: str, subject: str, to_list: str, cc_list: str, *args
):
    """ Send email with 1-3 attachments to given list of recipients. HTML body can also include inline chart if chart is also sent as an attachment.\n
    See Examples/Email_Strings.py \n
    Example Call - email_with_attachments(emailbody,subjectstring,to_list,cc_list,attachment1=r'c:/users/mjensen/report.xlsx',attachment2=r'c:/users/mjensen/report.doc',attachment3=r'c:/users/mjensen/report.ppt')

    :param message: HTML String with Email message contained. See Examples/Email_Body.html.
    :param subject: Subject String
    :param to_list: Semicolon separated list of email addresses. (ex - a@abc.com; b@abc.com; c@abc.com;)
    :param cc_list: Semicolon separated list of email addresses. (ex - a@abc.com; b@abc.com; c@abc.com;)
    """

    ol_mail_item = 0x0
    obj = Dispatch("Outlook.Application")
    new_mail = obj.CreateItem(ol_mail_item)
    new_mail.Subject = subject
    new_mail.GetInspector()
    new_mail.To = to_list
    new_mail.CC = cc_list
    for count, Path in enumerate(args):
        print("{0}. {1}".format(count, Path))
        new_mail.Attachments.Add(Source=Path)
    index = new_mail.HTMLbody.find(">", new_mail.HTMLbody.find("<body"))
    new_mail.HTMLbody = (
            new_mail.HTMLbody[: index + 1] + message + new_mail.HTMLbody[index + 1:]
    )
    # noinspection PyStatementEffect
    new_mail.send



from win32com.client import Dispatch
from datetime import datetime


def notify_error(report_name, error_log, to_list: str):
    """Auto-notify for automated scripts crashing.

    :param to_list: List of emails to receive notification.
    :param report_name: Name of automated report.
    :param error_log: Raised exception or other error to report.
    """
    ol_mail_item = 0x0
    obj = Dispatch("Outlook.Application")
    new_mail = obj.CreateItem(ol_mail_item)
    new_mail.Subject = f"Automated Report Error Notification - {report_name}"
    new_mail.GetInspector()
    message = f"""
                                 <HTML>
                                 <BODY>
                                 {report_name} failed on execution at {datetime.now().strftime("%d/%m/%Y %H:%M:%S")}
                                 <br>
                                 Error Log:
                                 <br>
                                 {error_log}
                                 <br>
                                 </BODY>
                                 </HTML>"""
    new_mail.To = to_list
    index = new_mail.HTMLbody.find(">", new_mail.HTMLbody.find("<body"))
    new_mail.HTMLbody = (
            new_mail.HTMLbody[: index + 1] + message + new_mail.HTMLbody[index + 1:]
    )
    # noinspection PyStatementEffect
    new_mail.send



# __init__.py
from .email_without_attachment import email_without_attachment
from .display_email import display_email
from .display_email_with_attachments import display_email_with_attachments
from .email_with_attachments import email_with_attachments
from .notify_error import notify_error
from .default_table_style import default_table_style
# Version of the package
__version__ = "1.3"



from win32com.client import Dispatch


def display_email(message: str, subject: str, to_list: str, cc_list: str):
    """Display draft of email.

        :param message: HTML String with Email message contained. See Examples/Email_Strings.py
        :param subject: Subject String
        :param to_list: Semicolon separated list of email addresses. (ex - a@abc.com; b@abc.com; c@abc.com;)
        :param cc_list: Semicolon separated list of email addresses. (ex - a@abc.com; b@abc.com; c@abc.com;)
        """
    ol_mail_item = 0x0
    obj = Dispatch("Outlook.Application")
    new_mail = obj.CreateItem(ol_mail_item)
    new_mail.Subject = subject
    new_mail.GetInspector()
    new_mail.To = to_list
    new_mail.CC = cc_list
    index = new_mail.HTMLbody.find(">", new_mail.HTMLbody.find("<body"))
    new_mail.HTMLbody = (
            new_mail.HTMLbody[: index + 1] + message + new_mail.HTMLbody[index + 1:]
    )
    # noinspection PyStatementEffect
    new_mail.display



from setuptools import setup, Extension, find_packages
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name="outlookutility",
    packages=['outlookutility'],
    version="1.3",
    author="Matthew Jensen",
    author_email="matt@matthewjensen.dev",
    description="Outlook email automation functions",
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/MattDJensen/Outlook_Utility_Package',
    download_url='https://github.com/MattDJensen/Outlook_Utility_Package/archive/1.3.tar.gz',
    license="MIT",
    setup_requires=['wheel'],
    install_requires=[
        'pywin32'
    ],
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Operating System :: Microsoft :: Windows :: Windows 10"
    ],
    python_requires='>=3.6',
)



import pandas as pd


def default_table_style(df, index: False):
    """ Apply a default clean table style to pandas df.to_html() for use in email strings.

    :param index: Determines whether you want index displayed in the HTML. Defaults to False.
    :type index: Boolean
    :param df: Dataframe to apply the style to.
    :type df: Pandas Dataframe
    :return: HTML string for insertion in email.
    :rtype: string
    """
    if index:
        df = '''
                <head>
                    <style>
                        table.dataframe {
                            border-collapse: collapse;
                        }
                        table.dataframe th{
                            border: 1px solid black;
                            padding: 10px;
                            font-size:14px;
                            text-align: center;
                        }
                        table.dataframe td {
                            border: 1px solid black;
                            padding: 10px;
                            font-size:12px;
                            text-align: center;
                        }
                    }
                    </style>
                </head>
                ''' + df.to_html()
    else:
        df = '''
                <head>
                    <style>
                        table.dataframe {
                            border-collapse: collapse;
                        }
                        table.dataframe th{
                            border: 1px solid black;
                            padding: 10px;
                            font-size:14px;
                            text-align: center;
                        }
                        table.dataframe td {
                            border: 1px solid black;
                            padding: 10px;
                            font-size:12px;
                            text-align: center;
                        }
                    }
                    </style>
                </head>
                ''' + df.to_html(index=False)
    return df
